==> hubzero-submit-client_2.5.7.orig.tar.gz: hubzero-submit-client-2.5.7/hubzero/submit/ClientIdAuthAttributes.py <==
# @package      hubzero-submit-client
# @file         ClientIdAuthAttributes.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import sys
import os
import getpass
import pwd

class ClientIdAuthAttributes:
   def __init__(self):
      self.sessionAttributes = {}
      self.userAttributes    = {}

      if 'SESSIONDIR' in os.environ:
         resourcePath = os.path.join(os.environ['SESSIONDIR'],'resources')
         self.getSessionAttributes(resourcePath)

      if not 'token' in self.sessionAttributes:
         if 'HOME' in os.environ:
            resourcePath = os.path.join(os.environ['HOME'],'.default_resources')
            self.getSessionAttributes(resourcePath)


   def getSessionAttributes(self,
                            resourcePath):
      del self.sessionAttributes
      self.sessionAttributes = {}

      try:
         if os.path.exists(resourcePath):
            fpResource = open(resourcePath,'r')
            if fpResource:
               eof = False
               while not eof:
                  record = fpResource.readline()
                  if record != "":
                     if   record.startswith('session_token '):
                        self.sessionAttributes['token'] = record.split()[1]
                     elif record.startswith('username '):
                        self.sessionAttributes['userName'] = record.split()[1]
                  else:
                     eof = True
               fpResource.close()
      except:
         pass


   def getUserAttributes(self):
      del self.userAttributes
      self.userAttributes = {}

      self.userAttributes['userName'] = getpass.getuser()
      haveToken = 'token' in self.sessionAttributes
      if not haveToken:
         si = sys.stdin
         sys.stdin = open('/dev/tty')
         try:
            username = raw_input("Username: (%s) " % (self.userAttributes['userName']))
            if username != "":
               self.userAttributes['userName'] = username
            password = getpass.getpass("Password: ")
            if password != "":
               self.userAttributes['password'] = password
         except Exception:
            pass
         sys.stdin = si

      try:
         (login,pw,uid,gid,name,homedir,shell) = pwd.getpwnam(self.userAttributes['userName'])
         self.userAttributes['userId'] = uid
      except:
         pass


   def haveIdAuthAttributes(self):
      haveAttributes = False
      if   'token' in self.sessionAttributes:
         haveAttributes = True
      elif 'userName' in self.userAttributes and 'password' in self.userAttributes:
         haveAttributes = True

      return(haveAttributes)


   def getSignonAttributes(self):
      signonAttributes = {}
      signonAttributes['userName']    = self.userAttributes['userName']
      if 'password' in self.userAttributes:
         signonAttributes['password'] = self.userAttributes['password']
      if 'userId' in self.userAttributes:
         signonAttributes['userId']   = self.userAttributes['userId']
      if 'token' in self.sessionAttributes:
         signonAttributes['token']    = self.sessionAttributes['token']

      return(signonAttributes)


   def clearSessionToken(self):
      if 'token' in self.sessionAttributes:
         del self.sessionAttributes['token']

==> hubzero-submit-client_2.7.2.orig.tar.gz: hubzero-submit-client-2.7.2/hubzero/submit/ClientIdAuthAttributes.py <==
# @package      hubzero-submit-client
# @file         ClientIdAuthAttributes.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import sys
import os
import getpass
import pwd
import logging

class ClientIdAuthAttributes:
   def __init__(self):
      self.logger            = logging.getLogger(__name__)
      self.sessionAttributes = {}
      self.userAttributes    = {}

      if 'SESSIONDIR' in os.environ:
         resourcePath = os.path.join(os.environ['SESSIONDIR'],'resources')
         self.getSessionAttributes(resourcePath)

      if not 'token' in self.sessionAttributes:
         if 'HOME' in os.environ:
            resourcePath = os.path.join(os.environ['HOME'],'.default_resources')
            self.getSessionAttributes(resourcePath)


   def getSessionAttributes(self,
                            resourcePath):
      del self.sessionAttributes
      self.sessionAttributes = {}

      try:
         if os.path.exists(resourcePath):
            fpResource = open(resourcePath,'r')
            if fpResource:
               eof = False
               while not eof:
                  record = fpResource.readline()
                  if record != "":
                     if   record.startswith('session_token '):
                        self.sessionAttributes['token'] = record.split()[1]
                     elif record.startswith('username '):
                        self.sessionAttributes['userName'] = record.split()[1]
                     elif record.startswith('sessionid '):
                        self.sessionAttributes['sessionId'] = record.split()[1]
                  else:
                     eof = True
               fpResource.close()
      except:
         pass


   def getUserAttributes(self):
      del self.userAttributes
      self.userAttributes = {}

      self.userAttributes['userName'] = getpass.getuser()
      haveToken = 'token' in self.sessionAttributes
      if not haveToken:
         si = sys.stdin
         sys.stdin = open('/dev/tty')
         try:
            username = raw_input("Username: (%s) " % (self.userAttributes['userName']))
            if username != "":
               self.userAttributes['userName'] = username
            password = getpass.getpass("Password: ")
            if password != "":
               self.userAttributes['password'] = password
         except Exception:
            pass
         sys.stdin = si

      try:
         (login,pw,uid,gid,name,homedir,shell) = pwd.getpwnam(self.userAttributes['userName'])
         self.userAttributes['userId'] = uid
      except:
         pass


   def haveIdAuthAttributes(self):
      haveAttributes = False
      if   'token' in self.sessionAttributes:
         haveAttributes = True
      elif 'userName' in self.userAttributes and 'password' in self.userAttributes:
         haveAttributes = True

      return(haveAttributes)


   def getSignonAttributes(self):
      signonAttributes = {}
      signonAttributes['userName']     = self.userAttributes['userName']
      if 'password' in self.userAttributes:
         signonAttributes['password']  = self.userAttributes['password']
      if 'userId' in self.userAttributes:
         signonAttributes['userId']    = self.userAttributes['userId']
      if 'sessionId' in self.sessionAttributes:
         signonAttributes['sessionId'] = self.sessionAttributes['sessionId']
      if 'token' in self.sessionAttributes:
         signonAttributes['token']     = self.sessionAttributes['token']

      return(signonAttributes)


   def clearSessionToken(self):
      if 'token' in self.sessionAttributes:
         del self.sessionAttributes['token']
